summaryrefslogtreecommitdiffstats
path: root/cervisia/entry.h
diff options
context:
space:
mode:
Diffstat (limited to 'cervisia/entry.h')
-rw-r--r--cervisia/entry.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/cervisia/entry.h b/cervisia/entry.h
index 2c0a1c98..f3705d35 100644
--- a/cervisia/entry.h
+++ b/cervisia/entry.h
@@ -43,7 +43,7 @@ struct Entry
};
/**
* Sets status to \a EntrytqStatus::Unknown and type to \a File.
*/
Entry();
@@ -60,7 +60,7 @@ struct Entry
/**
* The status of this entry.
*/
- EntrytqStatus m_status;
+ EntryStatus m_status;
/**
* The revision of this entry.
@@ -43,7 +43,7 @@ struct Entry
};
/**
- * Sets status to \a EntrytqStatus::Unknown and type to \a File.
+ * Sets status to \a EntryStatus::Unknown and type to \a File.
*/
Entry();